@@ -1,11 +1,12 @@
 import os
 from dataclasses import asdict, dataclass, field, replace
+from enum import Enum
 from pathlib import Path
 from typing import Any, Dict, Optional, Type
 
 import click
 from marshmallow_dataclass import class_schema
-from yaml import SafeLoader, load, safe_dump  # type: ignore
+from yaml import SafeLoader, load, safe_dump
 
 from streamingcli.config import (
     DEFAULT_PROFILE_DIR,
@@ -14,14 +15,30 @@ from streamingcli.config import (
 )
 
 
+class DeploymentMode(Enum):
+    VVP = "VVP"
+    K8S_OPERATOR = "K8S_OPERATOR"
+
+
+def custom_asdict_factory(data: Any) -> Dict[str, Any]:
+    def convert_value(obj: Any) -> Any:
+        if isinstance(obj, Enum):
+            return obj.value
+        return obj
+
+    return {k: convert_value(v) for k, v in data}
+
+
 @dataclass(repr=True)
 class ScliProfile:
     profile_name: str
+    deployment_mode: Optional[DeploymentMode] = field(default=DeploymentMode.VVP)
     ververica_url: Optional[str] = field(default=None)
     ververica_namespace: Optional[str] = field(default=None)
     ververica_deployment_target: Optional[str] = field(default=None)
     ververica_api_token: Optional[str] = field(default=None)
     docker_registry_url: Optional[str] = field(default=None)
+    k8s_namespace: Optional[str] = field(default=None)
 
 
 @dataclass
@@ -36,7 +53,12 @@ class ProfileAdapter:
         profiles = ProfileAdapter.load_profiles()
         profiles_dict = profiles.profiles
         profiles_dict[scli_profile.profile_name] = scli_profile
-        content = safe_dump(asdict(replace(profiles, profiles=profiles_dict)))
+        content = safe_dump(
+            asdict(
+                replace(profiles, profiles=profiles_dict),
+                dict_factory=custom_asdict_factory,
+            )
+        )
         with open(DEFAULT_PROFILE_PATH, "w+") as file:
             file.write(content)
 
@@ -77,13 +99,17 @@ class ProfileAdapter:
     @staticmethod
     def update_profile_data(
         profile_data: ScliProfile,
+        deployment_mode: Optional[DeploymentMode] = None,
         ververica_url: Optional[str] = None,
         ververica_namespace: Optional[str] = None,
         ververica_deployment_target_name: Optional[str] = None,
         ververica_webtoken_secret: Optional[str] = None,
         docker_registry_url: Optional[str] = None,
+        k8s_namespace: Optional[str] = None,
     ) -> ScliProfile:
-        params = {}
+        params = {}  # type: Dict[str, Any]
+        if deployment_mode is not None:
+            params["deployment_mode"] = deployment_mode
         if ververica_url is not None:
             params["ververica_url"] = ververica_url
         if ververica_namespace is not None:
@@ -94,6 +120,8 @@ class ProfileAdapter:
             params["ververica_api_token"] = ververica_webtoken_secret
         if docker_registry_url is not None:
             params["docker_registry_url"] = docker_registry_url
+        if k8s_namespace is not None:
+            params["k8s_namespace"] = k8s_namespace
 
         non_empty_params = {
             key: value for (key, value) in params.items() if value is not None
